@@ -1,31 +1,28 @@
-import asyncio
-
-from ratelimit import limits, sleep_and_retry
-
+"""
+Goal Zero Rest Api
+~~~~~~~~~~~~~~~~~~~~~
+:copyright: (c) 2020 by Robert Hillis.
+Not affiliated with Goal Zero. Credit for headers belongs to Goal Zero.
+:license: Apache 2.0, see LICENSE for more details.
+"""
 import asyncio
 import aiohttp
-from async_timeout import timeout
 
 from . import exceptions
 
-# pylint: disable=pointless-string-statement
-""":copyright: (c) 2020 by Robert Hillis.
-Not affiliated with Goal Zero. Credit for headers belongs to Goal Zero.
-:license: Apache 2.0, see LICENSE for more details."""
-
-
 HEADER = {
     "Content-Type": "application/json",
     "User-Agent": "YetiApp/1340 CFNetwork/1125.2 Darwin/19.4.0",
     "Connection": "keep-alive",
     "Accept": "application/json",
     "Accept-Language": "en-us",
-    "Content-Length": "19",
     "Accept-Encoding": "gzip, deflate",
     "Cache-Control": "no-cache",
 }
 TIMEOUT = 10
 
+semaphore = asyncio.Semaphore()
+
 
 class Yeti:
     """A class for handling connections with a Goal Zero Yeti."""
@@ -84,13 +81,13 @@ class Yeti:
         self.control = "app"
         await Yeti.send_get(self)
 
-    async def post_loglevel(self, payload: dict[str, int]) -> None:
+    async def post_loglevel(self, payload) -> None:
         """Post log level Goal Zero Yeti instance."""
         self.endpoint = "/loglevel"
         self.payload = payload
         await Yeti.send_post(self)
 
-    async def join(self, payload: dict) -> None:
+    async def join(self, payload) -> None:
         """Join Goal Zero Yeti instance to Wifi network."""
         self.endpoint = "/join"
         self.payload = payload
@@ -101,7 +98,7 @@ class Yeti:
         self.endpoint = "/wifi"
         await Yeti.send_get(self)
 
-    async def password_set(self, payload: str) -> None:
+    async def password_set(self, payload) -> None:
         """Set password to Zero Yeti instance."""
         self.payload = {"new_password": "" + payload + ""}
         self.endpoint = "/password-set"
@@ -117,14 +114,13 @@ class Yeti:
         self.endpoint = "/start-pair"
         await Yeti.send_post(self)
 
-    @sleep_and_retry
-    @limits(calls=1, period=2)
     async def send_get(self) -> None:
         """Send get request."""
         try:
-            async with timeout(TIMEOUT, loop=asyncio.get_running_loop()):
+            async with semaphore:
                 response = await self._session.get(
-                    "http://" + self.host + self.endpoint
+                    url=f"http://{self.host}{self.endpoint}",
+                    timeout=aiohttp.ClientTimeout(TIMEOUT),
                 )
                 if self.endpoint == "/sysinfo":
                     self.sysdata = await response.json()
@@ -144,16 +140,15 @@ class Yeti:
         except aiohttp.client_exceptions.ServerDisconnectedError:
             pass
 
-    @sleep_and_retry
-    @limits(calls=1, period=2)
     async def send_post(self) -> None:
         """Send post request."""
         try:
-            async with timeout(TIMEOUT, loop=asyncio.get_running_loop()):
+            async with semaphore:
                 request = await self._session.post(
-                    "http://" + self.host + self.endpoint,
+                    url=f"http://{self.host}{self.endpoint}",
                     json=self.payload,
                     headers=HEADER,
+                    timeout=aiohttp.ClientTimeout(TIMEOUT),
                 )
                 self.data = await request.json()
                 if self.data["socPercent"] > 100:
